dot-nncross: Alternative Interface of nncross.ppp

.nncrossR Documentation

Alternative Interface of nncross.ppp

Description

An alternative interface of the function nncross.ppp.

Usage

.nncross(X, i, j, ...)

Arguments

X

see Details

i, j

character or integer scalars. See functions Gcross, etc. for more details

...

additional parameters of nncross.ppp

Details

The function .nncross() creates an interface similar to The functions Gcross, etc., which takes an is.multitype ppp.object and two mark values i and j, then calls the workhorse function nncross.ppp with parameter what = 'dist'. If mark values i and j does not exist in the ppp.object, a NULL value will be returned.

Value

The function .nncross() returns a numeric vector if i and j are valid mark values of ppp.object X; otherwise returns a NULL value.

References

https://tingtingzhan.quarto.pub/groupedhyperframe/topics.html


groupedHyperframe documentation built on March 10, 2026, 5:08 p.m.