groupedHyperframe-package: groupedHyperframe: Grouped Hyper Data Frame

groupedHyperframe-packageR Documentation

groupedHyperframe: Grouped Hyper Data Frame

Description

Extensions of "hyper data frame" (from package 'spatstat.geom') with a grouping structure. The author has retired from academic research. Accordingly, this package should not be considered a validated tool for use in peer-reviewed publications or as the basis for grant applications. Backward compatibility with user-code published in \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1093/bioinformatics/btaf430")} is not maintained in versions >= 0.4.0 (June 2026) of this package. The authors of those publications are the appropriate contacts for reproducibility inquiries.

Note

This R package author has retired from academic research.

Accordingly, this package should not be considered a validated tool for use in peer-reviewed publications or as the basis for grant applications.

Backward compatibility with user-code published in the following publications is not maintained in versions ⁠>= 0.4.0⁠ of this package. The authors of those publications are the appropriate contacts for reproducibility inquiries.

\Sexpr[results=rd]{tools:::Rd_expr_doi("10.1093/bioinformatics/btaf430")}

Author(s)

Maintainer: Tingting Zhan tingtingzhan@gmail.com

Authors:


groupedHyperframe documentation built on Aug. 26, 2026, 1:08 a.m.