An alternative interface of the function nncross.ppp.
.nncross(X, i, j, ...)The function .nncross() returns
a numeric
if i and j are valid mark values of ppp.object
X;
otherwise returns a NULL value.
The function .nncross() creates an interface similar to
The functions Gcross, etc.,
which takes an is.multitype ppp.object
and two mark values i and j,
then calls the workhorse function
nncross.ppp with parameter what = 'dist'.
If mark values i and j does not exist in the ppp.object,
a NULL value will be returned.
https://tingtingzhan.quarto.pub/groupedhyperframe/topics.html