groupedHyperframe-package: groupedHyperframe: Grouped Hyper Data Frame

groupedHyperframe-packageR Documentation

groupedHyperframe: Grouped Hyper Data Frame

Description

To aggregate a hyper data frame, defined in the package 'spatstat.geom', according to a grouping structure. To facilitate downstream analysis based on a "grouped" hyper data frame. The author has retired from academic research. Accordingly, this package should not be considered a validated tool for use in peer-reviewed publications or as the basis for grant applications. Backward compatibility with user-code published in \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1093/bioinformatics/btaf430")} is not maintained in versions >= 0.4.0 of this package. The authors of those publications are the appropriate contacts for reproducibility inquiries.

Note

This R package author has retired from academic research.

Accordingly, this package should not be considered a validated tool for use in peer-reviewed publications or as the basis for grant applications.

Backward compatibility with user-code published in the following publications is not maintained in versions ⁠>= 0.4.0⁠ of this package. The authors of those publications are the appropriate contacts for reproducibility inquiries.

\Sexpr[results=rd]{tools:::Rd_expr_doi("10.1093/bioinformatics/btaf430")}

Author(s)

Maintainer: Tingting Zhan tingtingzhan@gmail.com (ORCID)

Authors:

See Also

Useful links:


groupedHyperframe documentation built on June 21, 2026, 5:11 p.m.