| groupedHyperframe-package | R Documentation |
To aggregate a hyper data frame, defined in the package 'spatstat.geom', according to a grouping structure. To facilitate downstream analysis based on a "grouped" hyper data frame. The author has retired from academic research. Accordingly, this package should not be considered a validated tool for use in peer-reviewed publications or as the basis for grant applications. Backward compatibility with user-code published in \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1093/bioinformatics/btaf430")} is not maintained in versions >= 0.4.0 of this package. The authors of those publications are the appropriate contacts for reproducibility inquiries.
This R package author has retired from academic research.
Accordingly, this package should not be considered a validated tool for use in peer-reviewed publications or as the basis for grant applications.
Backward compatibility with user-code published in the following publications is not maintained in versions >= 0.4.0 of this package. The authors of those publications are the appropriate contacts for reproducibility inquiries.
Maintainer: Tingting Zhan tingtingzhan@gmail.com (ORCID)
Authors:
Tingting Zhan tingtingzhan@gmail.com (ORCID)
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.